==> haskell-modern-uri-0.3.6.1-100-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-modern-uri.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 modern-uri
version:              0.3.6.1
visibility:           public
id:                   modern-uri-0.3.6.1-4z2J5xTFtav6tKTkupgvnf
key:                  modern-uri-0.3.6.1-4z2J5xTFtav6tKTkupgvnf
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/modern-uri
synopsis:             Modern library for working with URIs
description:          Modern library for working with URIs.
category:             Text
abi:                  eed08b3860675da89121c05731f5bd43
exposed:              True
exposed-modules:      Text.URI Text.URI.Lens Text.URI.QQ
hidden-modules:
    Text.URI.Parser.ByteString Text.URI.Parser.Text
    Text.URI.Parser.Text.Utils Text.URI.Render Text.URI.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/modern-uri-0.3.6.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/modern-uri-0.3.6.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/modern-uri-0.3.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-modern-uri
hs-libraries:         HSmodern-uri-0.3.6.1-4z2J5xTFtav6tKTkupgvnf
depends:
    QuickCheck-2.14.3-CUJERxKFpT5Wrs3HEJyvt base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    exceptions-0.10.5 hashable-1.4.4.0-2lvxXC6j7O5I2GR31C0SqX
    megaparsec-9.7.0-DoL2miG02BJ8XUb2sfozR5 mtl-2.2.2
    profunctors-5.6.3-63mQtfUXOTH6K8o94A7vA
    reflection-2.1.9-Fqnm9dXtDilBSIoQe8KhP3
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C template-haskell-2.19.0.0
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-modern-uri/html/modern-uri.haddock
haddock-html:         /usr/share/doc/haskell-modern-uri/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-modern-uri-0.3.6.1-101-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-modern-uri.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 modern-uri
version:              0.3.6.1
visibility:           public
id:                   modern-uri-0.3.6.1-BG5RKgzNBfhCPItmOIdcIH
key:                  modern-uri-0.3.6.1-BG5RKgzNBfhCPItmOIdcIH
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/modern-uri
synopsis:             Modern library for working with URIs
description:          Modern library for working with URIs.
category:             Text
abi:                  025c449e4099c11d54123895f9a308d7
exposed:              True
exposed-modules:      Text.URI Text.URI.Lens Text.URI.QQ
hidden-modules:
    Text.URI.Parser.ByteString Text.URI.Parser.Text
    Text.URI.Parser.Text.Utils Text.URI.Render Text.URI.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/modern-uri-0.3.6.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/modern-uri-0.3.6.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/modern-uri-0.3.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-modern-uri
hs-libraries:         HSmodern-uri-0.3.6.1-BG5RKgzNBfhCPItmOIdcIH
depends:
    QuickCheck-2.14.3-4HbOe3sBZbX6PbIkQ49pGG base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    exceptions-0.10.5 hashable-1.4.4.0-AFqmlTE0BBaCoTGEV5znl2
    megaparsec-9.7.0-2LveF0uKMovFZzLupvHuy3 mtl-2.2.2
    profunctors-5.6.3-CZGRj4axmFA9bHsS9eciFX
    reflection-2.1.9-4sTzoiCxEfoGauTHK09ZMD
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C template-haskell-2.19.0.0
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-modern-uri/html/modern-uri.haddock
haddock-html:         /usr/share/doc/haskell-modern-uri/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
